@@ -9,7 +9,6 @@ import enum
 import itertools
 import re
 import typing as t
-import warnings
 from abc import ABC, abstractmethod
 from base64 import b64encode
 from collections import deque
@@ -25,7 +24,7 @@ from lxml.etree import Element
 from pandas.io.formats.style import Styler
 
 from datapane.client import DPError
-from datapane.common import PKL_MIMETYPE, NPath, guess_type
+from datapane.common import PKL_MIMETYPE, NPath, guess_type, utf_read_text
 from datapane.common.report import conv_attribs, get_embed_url, is_valid_id
 
 from ..common import DPTmpFile
@@ -206,22 +205,17 @@ class Page(LayoutBlock):
         *arg_blocks: BlockOrPrimitive,
         blocks: t.List[BlockOrPrimitive] = None,
         title: str = None,
-        label: str = None,
     ):
         """
         Args:
             *arg_blocks: Blocks to add to Page
             blocks: Allows providing the report blocks as a single list
             title: The page title (optional)
-            label: A label used when displaying the page (optional, deprecated)
 
         ..tip:: Page can be passed using either arg parameters or the `blocks` kwarg, e.g.
           `dp.Page(group, select)` or `dp.Group(blocks=[group, select])`
         """
-        if label:
-            warnings.warn("dp.Page label= argument is deprecated, to be removed in next release, use title= instead.")
-        label = label or title
-        super().__init__(*arg_blocks, blocks=blocks, label=label)
+        super().__init__(*arg_blocks, blocks=blocks, label=title)
         if len(self.blocks) < 1:
             raise DPError("Can't create Page with no objects")
         self._wrap_blocks()
@@ -362,17 +356,19 @@ class Text(EmbeddedTextBlock):
 
     def __init__(self, text: str = None, file: NPath = None, name: str = None, label: str = None):
         """
-        Args:te
+        Args:
             text: The markdown formatted text, use triple-quotes, (`\"\"\"# My Title\"\"\"`) to create multi-line markdown text
             file: Path to a file containing markdown text
             name: A unique name for the block to reference when adding text or embedding (optional)
+
+        ..note:: File encodings are auto-detected, if this fails please read the file manually with an explicit encoding and use the text parameter on dp.File
         """
         super().__init__(name=name, label=label)
 
         if text:
             text = text.strip()
         assert text or file
-        self.content = text if text else Path(file).read_text()
+        self.content = text or utf_read_text(Path(file).expanduser())
 
     def format(self, *args: BlockOrPrimitive, **kwargs: BlockOrPrimitive) -> Group:
         """
@@ -580,7 +576,7 @@ class AssetBlock(DataBlock):
             # load the file and embed into a data-uri
             # NOTE - currently we read entire file into memory first prior to b64 encoding,
             #  to consider using base64io-python to stream and encode in 1-pass
-            content = b64encode(self.file.read_bytes()).decode()
+            content = b64encode(self.file.read_bytes()).decode("ascii")
             e = _E(
                 type=content_type,
                 size=file_size,
@@ -636,7 +632,7 @@ class File(AssetBlock):
         ..note:: either `data` or `file` must be provided
         """
         if file:
-            file = Path(file)
+            file = Path(file).expanduser()
         else:
             out_fn = self._save_obj(data, as_json=is_json)
             file = out_fn.file
@@ -676,11 +672,10 @@ class Table(AssetBlock):
     """
     Table blocks store the contents of a dataframe as a HTML `table` whose style can be customised using
     pandas' `Styler` API.
-
-    ..note:: Please use Table component when saving files locally over the DataTable component which has more features but requires publishing your report
-
     """
 
+    # NOTE - Tables are stored as HTML fragment files rather than inline within the Report document
+
     _tag = "Table"
 
     def __init__(
