@@ -5,15 +5,15 @@ Describes the `Report` object and included APIs for saving and uploading them.
 """
 import dataclasses as dc
 import json
-import shutil
+import random
 import typing as t
-import warnings
 import webbrowser
 from base64 import b64encode
-from enum import Enum, IntEnum
+from enum import Enum
 from functools import reduce
 from os import path as osp
 from pathlib import Path
+from uuid import uuid4
 
 import importlib_resources as ir
 from jinja2 import Environment, FileSystemLoader, Markup, Template, contextfunction
@@ -55,16 +55,6 @@ __pdoc__ = {
 }
 
 
-# TODO(protocol) TODO(obsolete)
-class Visibility(IntEnum):
-    """The report visibility type"""
-
-    PRIVATE = 0  # private to owner
-    # UNLISTED = 1  # public but not searchable
-    PUBLIC = 2  # anon/unauthed access
-
-
-# TODO(protocol)
 class ReportWidth(Enum):
     """The document width"""
 
@@ -73,14 +63,6 @@ class ReportWidth(Enum):
     FULL = "full"
 
 
-class ReportType(Enum):
-    """The document type"""
-
-    DASHBOARD = "dashboard"
-    REPORT = "report"
-    ARTICLE = "article"
-
-
 class TextAlignment(Enum):
     JUSTIFY = "justify"
     LEFT = "left"
@@ -161,28 +143,13 @@ class ReportFileWriter:
 
         # load the logo
         logo_img = (self.assets / "datapane-logo-dark.png").read_bytes()
-        self.logo = f"data:image/png;base64,{b64encode(logo_img).decode()}"
+        self.logo = f"data:image/png;base64,{b64encode(logo_img).decode('ascii')}"
 
         template_loader = FileSystemLoader(self.assets)
         template_env = Environment(loader=template_loader)
         template_env.globals["include_raw"] = include_raw
         self.template = template_env.get_template("template.html")
 
-    def _display_msg(self):
-        # TODO(obsolete)
-        global SKIP_DISPLAY_MSG
-
-        # only display once per session, else skip
-        if SKIP_DISPLAY_MSG or c.config.is_org:
-            return None
-        else:
-            SKIP_DISPLAY_MSG = True
-
-        display_msg(
-            text="Thanks for using Datapane, to automate and securely share documents in your organization please see Datapane Teams - https://datapane.com/",
-            md="Thanks for using **Datapane**, to automate and securely share documents in your organization please see [Datapane Teams](https://datapane.com/)",
-        )
-
     def write(
         self,
         report_doc: str,
@@ -205,9 +172,6 @@ class ReportFileWriter:
             md=f"Report saved to {path}. To host and share securely, [request a free private workspace]({url})",
         )
 
-        # TODO(obsolete)
-        # self._display_msg()
-
         # template.html inlines the report doc with backticks so we need to escape any inside the doc
         report_doc_esc = report_doc.replace("`", r"\`")
         r = self.template.render(
@@ -297,14 +261,15 @@ class BaseReport(DPObjectRef):
         formatting_kwargs = {}
 
         if formatting:
-            if c.config.is_org:
-                formatting_kwargs.update(width=formatting.width.value)
-            else:
-                formatting_kwargs.update(
-                    width=formatting.width.value,
-                    css_header=formatting.to_css(),
-                    is_light_prose=formatting.light_prose,
-                )
+            formatting_kwargs.update(
+                width=formatting.width.value,
+                style_header=(
+                    f'<style type="text/css">\n{formatting.to_css()}\n</style>'
+                    if c.config.is_org
+                    else formatting.to_css()
+                ),
+                is_light_prose=formatting.light_prose,
+            )
 
         kwargs.update(
             name=name,
@@ -320,12 +285,9 @@ class BaseReport(DPObjectRef):
 
         # generate the report
         report_str, attachments = self._gen_report(embedded=False, title=name, description=description)
-        # TODO(protocol) always include attachments parameter
-        # if not attachments:
-        #     kwargs["attachments"] = []
         files = dict(attachments=attachments)
 
-        # create a temp output file for stripped down version of notebook
+        # create empty temp file to potentially store stripped down notebook
         with DPTmpFile(".ipynb") as output_file:
             if source_file:
                 # strip the output of original notebook and store in temp file
@@ -480,6 +442,7 @@ class Report(BaseReport):
     _last_saved: t.Optional[str] = None  # Path to local report
     _tmp_report: t.Optional[Path] = None  # Temp local report
     _local_writer = ReportFileWriter()
+    _preview_file: str = DPTmpFile(f"{uuid4().hex}.html")
     list_fields: t.List[str] = ["name", "web_url", "group"]
     """When set, the report is full-width suitable for use in a dashboard"""
 
@@ -487,7 +450,6 @@ class Report(BaseReport):
         self,
         *arg_blocks: PageOrPrimitive,
         blocks: t.List[PageOrPrimitive] = None,
-        type: ReportType = ReportType.REPORT,
         **kwargs,
     ):
         """
@@ -505,10 +467,6 @@ class Report(BaseReport):
         .. tip:: Create a list first to hold your blocks to edit them dynmically, for instance when using Jupyter, and use the `blocks` parameter
         """
         super().__init__(**kwargs)
-
-        if type:
-            warnings.warn("use dp.ReportFormatting instead when calling upload or save")
-
         self._preprocess_pages(blocks or list(arg_blocks))
 
     def _preprocess_pages(self, pages: t.List[BlockOrPrimitive]):
@@ -549,19 +507,7 @@ class Report(BaseReport):
             formatting: Set the basic styling for your report
         """
 
-        # TODO(protocol)
-        if "visibility" in kwargs:
-            kwargs.pop("visibility")
-            if c.config.is_public:
-                warnings.warn(
-                    "Visibility parameter deprecated, your reports are drafts by default and can be published via the report share feature in your browser"
-                )
-            else:
-                warnings.warn(
-                    "Visibility parameter deprecated, your reports are private by default and can be shared via the report share feature in your browser"
-                )
-
-        display_msg("Publishing document and associated data - *please wait...*")
+        display_msg("Uploading report and associated data - *please wait...*")
 
         self._upload_report(name, description, source_url, tags, group, source_file, formatting=formatting, **kwargs)
 
@@ -569,14 +515,10 @@ class Report(BaseReport):
             webbrowser.open_new_tab(self.web_url)
 
         display_msg(
-            text=f"Report successfully uploaded at {self.web_url}, follow the link to view your report and optionally share it with the Datapane Community",
-            md=f"Report successfully uploaded, click [here]({self.web_url}) to view your report and optionally share it with the Datapane Community",
+            text=f"Report successfully uploaded at {self.web_url}, follow the link to view and share your report",
+            md=f"Report successfully uploaded, click [here]({self.web_url}) to view and share your report",
         )
 
-    def publish(self, *a, **kw) -> None:
-        warnings.warn("Deprecated - please use report.upload instead")
-        self.upload(*a, **kw)
-
     @capture_event("CLI Report Save")
     def save(
         self,
@@ -608,45 +550,20 @@ class Report(BaseReport):
             formatting=formatting,
         )
 
+        # feedback form
+        if random.random() < 0.05:
+            display_msg(
+                text="How is your experience of Datapane? Please take two minutes to answer our anonymous product survey at https://bit.ly/3lWjRlr",
+                md="How is your experience of Datapane? Please take two minutes to answer our anonymous [product survey](https://bit.ly/3lWjRlr)",
+            )
+
         if open:
             path_uri = f"file://{osp.realpath(osp.expanduser(path))}"
             webbrowser.open_new_tab(path_uri)
 
     @capture_event("CLI Report Preview")
-    def preview(self, width: int = 960, height: int = 700):
-        """
-        Preview the document inside your currently running Jupyter notebook
-
-        Args:
-            width: Width of the preview in Jupyter (default: 960)
-            height: Height of the preview in Jupyter (default: 700)
-        """
-        warnings.warn(
-            "report.preview is deprecated, recommend using report.save instead and opening in a new browser tab"
-        )
-        if is_jupyter():
-            from IPython.display import IFrame
-
-            # Remove the previous temp report if it's been generated
-            if self._tmp_report and self._tmp_report.exists():
-                self._tmp_report.unlink()
-
-            # We need to copy the report HTML to a local temp file,
-            # as most browsers block iframes to absolute local paths.
-            tmpfile = DPTmpFile(ext=".html")
-            if self._last_saved:
-                # Copy to tmp file if already saved
-                shutil.copy(self._last_saved, tmpfile.name)
-            else:
-                # Else save directly to tmp file
-                self.save(path=tmpfile.name)
-            self._tmp_report = tmpfile.file
-
-            # NOTE - iframe must be relative path
-            iframe_src = self._tmp_report.relative_to(Path(".").absolute())
-            return IFrame(src=str(iframe_src), width=width, height=height)
-        else:
-            log.warning("Can't preview - are you running in Jupyter?")
+    def preview(self) -> None:
+        self.save(self._preview_file.name, open=True)
 
     def _report_status_checks(self, processed_report_doc: etree._ElementTree, embedded: bool, check_empty: bool):
         super()._report_status_checks(processed_report_doc, embedded, check_empty)
@@ -660,15 +577,17 @@ class Report(BaseReport):
             asset_blocks = processed_report_doc.xpath("count(/Report/Main//*)")
             if asset_blocks < 3 and check_empty:
                 raise InvalidReportError("Empty report - must contain at least one asset/block")
-            elif asset_blocks < 4:
-                url = "https://docs.datapane.com/reports/blocks/layout-pages-and-selects"
-                display_msg(
-                    text=f"Your report only contains a single element - did you know you can include additional plots, tables and text in a report? Check out {url} for more info",
-                    md=f"Your report only contains a single element - did you know you can include additional plots, tables and text in a report? Check out [the docs]({url}) for more info",
-                )
+            elif c.config.is_public:
+                # only nudge public users
+                if asset_blocks < 4:
+                    url = "https://docs.datapane.com/reports/blocks/layout-pages-and-selects"
+                    display_msg(
+                        text=f"Your report only contains a single element - did you know you can include additional plots, tables and text in a single report? Check out {url} for more info",
+                        md=f"Your report only contains a single element - did you know you can include additional plots, tables and text in a single report? Check out [the docs]({url}) for more info",
+                    )
 
-            has_text: bool = processed_report_doc.xpath("boolean(/Report/Main/Page//Text)")
-            if not has_text:
-                display_msg(
-                    "Your report doesn't contain any text - consider using TextReport to upload assets and add text to your report from your browser"
-                )
+                # has_text: bool = processed_report_doc.xpath("boolean(/Report/Main/Page//Text)")
+                # if not has_text:
+                #     display_msg(
+                #         "Your report doesn't contain any text - consider using TextReport to upload assets and add text to your report from your browser"
+                #     )
