@@ -16,11 +16,12 @@ from requests import HTTPError
 from tabulate import tabulate
 
 from datapane import __rev__, __version__
-from datapane.common import SDict, _setup_dp_logging, log
+from datapane.common import DPError, SDict, _setup_dp_logging, dict_drop_empty, log
+from datapane.common.dp_types import add_help_text
 
 from . import analytics, api
 from . import config as c
-from . import scripts, utils
+from . import scripts
 from .scripts import config as sc
 from .utils import failure_msg, process_cmd_param_vals, success_msg
 
@@ -80,10 +81,10 @@ class GlobalCommandHandler(click.Group):
             analytics.capture("CLI Error", dict(msg=str(e), type=str(type(e))))
             if EXTRA_OUT:
                 log.exception(e)
-            if isinstance(e, utils.DPError):
+            if isinstance(e, DPError):
                 failure_msg(str(e))
             else:
-                failure_msg(utils.add_help_text(str(e)), do_exit=True)
+                failure_msg(add_help_text(str(e)), do_exit=True)
 
 
 def recursive_help(cmd, parent=None):
@@ -246,7 +247,7 @@ def deploy(name: Optional[str], script: Optional[str], config: Optional[str], gr
     script = script and Path(script)
     config = config and Path(config)
     init_kwargs = dict(name=name, script=script, config_file=config, group=group)
-    kwargs = {k: v for k, v in init_kwargs.items() if v is not None}
+    kwargs = dict_drop_empty(init_kwargs, none_only=True)
 
     # if not (script or config or sc.DatapaneCfg.exists()):
     #     raise DPError(f"Not valid project dir")
@@ -346,12 +347,11 @@ def report():
 # @report.command()
 # @click.argument("name")
 # @click.argument("files", type=click.Path(), nargs=-1, required=True)
-# @click.option("--visibility", type=click.Choice(["PUBLIC", "PRIVATE"]))
-# def create(files: Tuple[str], name: str, visibility: str):
+# def create(files: Tuple[str], name: str):
 #     """Create a Report from the provided FILES"""
 #     blocks = [api.Asset.upload_file(file=Path(f)) for f in files]
 #     r = api.Report(*blocks)
-#     r.publish(name=name, visibility=visibility)
+#     r.upload(name=name)
 #     success_msg(f"Created Report {r.web_url}")
 
 
